@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -283,7 +283,9 @@ sub _count_padvars {
 
             # Under Perl 5.22.0+, $pv can end up as undef in some cases. With
             # a threaded Perl, instead of undef we see an empty string.
-            if(defined $pv && length $pv && $pv ne '&' && !($padname->FLAGS & B::SVpad_OUR)){
+            #
+            # $pv can also end up as just '$' or '&'.
+            if(defined $pv && length $pv && $pv ne '&' && $pv ne '$' && !($padname->FLAGS & B::SVpad_OUR)){
                 my %p;
 
                 $p{name}    = $pv;
@@ -427,7 +429,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.008.
+This document describes Test::Vars version 0.009.
 
 =head1 SYNOPSIS
 
